A flexible framework for assessing the quality of evidence for decision-making
==============================================================================

Decision-makers in government and elsewhere are often confronted with a
set of evidence for issues they have to consider. Some way of sorting
this evidence according to quality is almost always required, especially
when this evidence provides conflicting views, and is heterogeneous in
nature. There is a large body of tools, usually involving the
construction of checklist for ‘grading’ the evidence against an ordinal
scale. Decision-makers, however, face two problems when trying to use
these tools. The first is that they are too prescriptive; they fail to
account for the variety of contexts and problems that decision-makers
may face. The second problem, related to the first, is that individual
tools do not include all the criteria for judging quality that
decision-makers usually desire (Dempik, Becker, and Bryman, 2007).

In this paper we take a different approach to guide the
assessment of evidence quality. These tools for judging evidence
quality can be likened to expert opinions that can be brought
together to develop some overarching set of quality criteria. This
allows an _empirical_ rather than *a priori* formulation of the factors
that determine evidence quality. Our aim is to draw out these criteria
from the literature, and present these in a format which will allow
decision-makers to construct their own scales for assessing evidence
quality suited to their needs, capacity, and context. In other words, we
provide a framework that identifies the criteria that others have
identified as appropriate for judging evidence quality, leaving it to
the decision-maker to craft this framework into an operational tool that
meets their specific needs.

We apply our framework to illustrate its utility to a current issue of
policy importance in Australia.

Methodology
-----------
In searching for papers discussing evidence hierarchies, we searched the
UNSW Library collection of databases, which contain 475 databases,
related to various subject and policy areas, including health, education
and science. The search was conducted using the keywords “evidence
hierarchy”, “evidence levels” and “levels of evidence”, and filtered to
only include English language peer-reviewed papers from the year 2000
onwards.

In addition to searching academic databases, we also conducted a Google
search for evidence hierarchies specific to government agencies using
the same keywords with “.gov” and “filetype:pdf .gov” as suffixes in
order to yield results of evidence hierarchies and criteria templates
from government agencies.

Papers were included if they contained comprehensive guidance on ranking
evidence. This means that they either offered a full set of levels of
evidence or a hierarchy, or instead offered some other classification
system. In searching the UNSW database we restricted the search to
papers in peer-reviewed journals from 2000 onwards.

Additionally, only one article was used for this paper when a particular
evidence hierarchy was published twice (for example, the same authors
publishing the same evidence hierarchy in two journals under different
titles).

It follows on from the above that we excluded any articles that did not
contain any evidence hierarchies/levels/or schemes of analysis. Among
these types of articles included those that made suggestions for
existing evidence hierarchies, discussed philosophical and
implementation issues of using evidence-based approaches in a particular
field or research guidance based on evidence-based principles, as this
paper seeks focuses on types of evidence levels or hierarchies.

This search process yielded a final count of 28 papers and documents
containing proposed guidelines for judging the quality of evidence,
which are summarized in Table \_\_.

Dimensions of research quality
------------------------------

A review of this material suggests 5 common dimensions of quality to
judge evidence. These dimensions of evidence quality are summarized in
Table 1.

quality
